@@ -27,16 +27,6 @@ import warnings
 from contextlib import contextmanager
 from functools import lru_cache, partial
 
-import numba  # noqa: F401
-import numpy as np  # noqa: F401
-from numba import float64, njit  # noqa: F401
-
-from .build_f2c import install_f2c_if_needed
-from .build_gsl import install_gsl_if_needed
-from .build_lsoda import install_lsoda_if_needed
-from .build_lsoda_fast import install_lsoda_fast_if_needed
-from .integral import IntegralFunctionWrapper
-from .ode_fast import read_new_traces
 from .utils import (
     align,
     base_cache_folder,
@@ -75,6 +65,11 @@ def compile_if_needed_and_load(
     compilation_flags,
     cache_folder=None,
 ):
+    from .build_f2c import install_f2c_if_needed
+    from .build_gsl import install_gsl_if_needed
+    from .build_lsoda import install_lsoda_if_needed
+    from .build_lsoda_fast import install_lsoda_fast_if_needed
+
     if cache_folder is None:
         cache_folder = base_cache_folder()
 
@@ -116,6 +111,8 @@ def generate_files_and_compile_if_needed(
     compilation_flags,
 ):
 
+    from .integral import IntegralFunctionWrapper
+
     IntegralFunctionWrapper.reset()
 
     if glob.glob(
@@ -153,6 +150,8 @@ def generate_files_and_compile_if_needed(
 
 @lru_cache()
 def warn_new_traces(unique_id):
+    from .ode_fast import read_new_traces
+
     if read_new_traces(unique_id):
         warnings.warn("there are new permuations pending, you might want to recompile")
 
@@ -184,17 +183,18 @@ class LoadedModule:
         for unique_id in self._module.get_fast_ode_unique_ids().values():
             warn_new_traces(unique_id)
 
-        self._setup_functions()
-
-    def _setup_functions(self):
-        for name in self._module._api:
-            _fun = setup_function(name, self._module)
-            setattr(self._module, name, _fun)
-
     def reload(self):
         self._load()
 
     def __getattr__(self, name):
+        if name.startswith("solve_fast"):
+            solver = getattr(self._module, name)
+            return partial(solver, self._module)
+        if name in self._module._api:
+            _fun = setup_function(name, self._module)
+            setattr(self._module, name, _fun)
+            return _fun
+
         return getattr(self._module, name)
 
     def __getstate__(self):
@@ -213,7 +213,12 @@ class LoadedModule:
         return self._module.__dir__()
 
 
+@lru_cache
 def setup_function(name, module):
+    import numba  # noqa: F401
+    import numpy as np  # noqa: F401
+    from numba import float64, njit  # noqa: F401
+
     res_spec, arg_types, args, vector_flags, numba_signature = module._api[name]
 
     capsule = module.__pyx_capi__[f"_api_{name}"]
@@ -242,6 +247,7 @@ def setup_function(name, module):
     )
     code = align(
         f"""
+    |import numpy as np
     |{numba_decorator}
     |def {name}({arg_decl}):
     |    __result = np.zeros({res_shape if res_shape is not None else (1,)})
@@ -259,6 +265,7 @@ def setup_function(name, module):
     lo = dict(locals())
     gl = dict(globals())
     gl["fun"] = fun
+    gl["np"] = np
     exec(code, gl, lo)
     return lo[name]
 
