@@ -49,7 +49,10 @@ class Alias:
         return "Alias({}={})".format(self.name, self.symbols)
 
 
-class InternalFunction(sp.Function("Function", nargs=3, real=True)):
+F_with_three_args = sp.Function("Function", nargs=3, real=True)
+
+
+class InternalFunction(F_with_three_args):
     def __new__(clz, name, expressions, *args):
 
         # fix after unpickling
@@ -62,7 +65,9 @@ class InternalFunction(sp.Function("Function", nargs=3, real=True)):
         aliases = [a for a in args if isinstance(a, Alias)]
         args = [a.as_vector if isinstance(a, Alias) else a for a in args]
 
-        instance = super().__new__(clz, name, sp.Matrix(expressions), tuple(args))
+        instance = F_with_three_args.__new__(
+            clz, name, sp.Matrix(expressions), tuple(args)
+        )
 
         instance.aliases = aliases
         instance._unique_id = None
