@@ -99,11 +99,11 @@ class InterpolationFunction1DWrapper(WrapperBase):
         return align(
             """
             |extern "C" {{
-            |   double         _{name}(double x);
-            |   void           _set_{name}_values(double *, double *, size_t);
+            |   void         _set_{name}_values(double *, double *, size_t);
             |}}
             |
             |extern "C" double __ip_{name}(double);
+            |extern "C" void   __ip_sorted_{name}(double *, size_t, double *);
             |
             |extern "C" double  * _{name}_x_min_p, * _{name}_x_max_p;
             |extern "C" double  * _get_x_{name}();
@@ -195,6 +195,18 @@ class InterpolationFunction1DWrapper(WrapperBase):
             |         set_error_message("you must call set_{name}_values first");
             |     return result;
             |}}
+            |
+            |extern "C" void __ip_sorted_{name}(double *x, size_t n, double* y) {{
+            |     if ({name}_spline) {{
+            |         cspline_eval_vector_sorted({name}_spline->interp->state,
+            |                                    {name}_spline->x,
+            |                                    {name}_spline->y,
+            |                                    {name}_spline->interp->size,
+            |                                    x, n, y);
+            |     }}
+            |     else
+            |         set_error_message("you must call set_{name}_values first");
+            |}}
             """.format(
                 name=self.name
             )
@@ -217,6 +229,7 @@ class InterpolationFunction1DWrapper(WrapperBase):
             """
         |cdef extern from "{header_file_path}":
         |    double __ip_{name}(double);
+        |    void   __ip_sorted_{name}(double *, size_t, double *);
         |    double _set_{name}_values(double *, double *, size_t);
         |    double  * _{name}_x_min_p, * _{name}_x_max_p;
         |    double  * _get_x_{name}();
@@ -228,7 +241,6 @@ class InterpolationFunction1DWrapper(WrapperBase):
         )
 
     def cython_function_wrapper(self):
-
         yield align(
             """
         |def set_{name}_values(np.ndarray[np.double_t, ndim=1, cast=True, mode="c"] x,
@@ -238,6 +250,13 @@ class InterpolationFunction1DWrapper(WrapperBase):
         |    assert len(x) > 0, "empty array not allowed"
         |    _set_{name}_values(&x[0], &y[0], len(x))
         |
+        |def ip_sorted_{name}(np.ndarray[np.double_t, ndim=1, cast=True] x):
+        |    cdef result = np.zeros_like(x, np.float64)
+        |    cdef double[:] _result = result
+        |    cdef double[:] _x = x.ravel()
+        |    __ip_sorted_{name}(&_x[0], x.shape[0], &_result[0])
+        |    return result
+        |
         |def get_x_{name}():
         |    if _get_x_{name}() == NULL:
         |       return None
