@@ -1,8 +1,11 @@
       subroutine lsodafast(f, econ, neq, y, t, tout, itol, rtol, atol,
      1            itask, istate, iopt, rwork, lrw, iwork, liw, jac, jt,
-     2            lu_solver, fnorm_computation)
+     2            lu_solver, fnorm_computation, step_size_callback,
+     3            handle)
       external f, econ, jac, lu_solver, fnorm_computation
+      external step_size_callback
       integer neq, itol, itask, istate, iopt, lrw, iwork, liw, jt, isav
+      integer*8 handle
       double precision y, t, tout, rtol, atol, rwork, rsav
       dimension neq(1), y(1), rtol(1), atol(1), rwork(lrw), iwork(liw)
       dimension rsav(240), isav(50)
@@ -1022,7 +1025,6 @@ c if istate .gt. 1 but the flag init shows that initialization has
 c not yet been done, an error return occurs.
 c if istate = 1 and tout = t, jump to block g and return immediately.
 c-----------------------------------------------------------------------
-c      write(*, *) 'neq', neq
 c      write(*, *) 't', t
 c      write(*, *) 'tout', tout
 c      write(*, *) 'itol', itol
@@ -1379,7 +1381,7 @@ c-----------------------------------------------------------------------
       call stoda (neq, y, rwork(lyh), nyh, rwork(lyh), rwork(lewt),
      1   rwork(lsavf), rwork(lacor), rwork(lwm), iwork(liwm),
      2   f, jac, prja, solsy, econ, rwork(llasty), lu_solver,
-     3   fnorm_computation)
+     3   fnorm_computation, step_size_callback, handle)
 c     SCIPY error check:
       if (neq(1) .eq. -1) return
       kgo = 1 - kflag
