@@ -1,9 +1,10 @@
       subroutine stoda (neq, y, yh, nyh, yh1, ewt, savf, acor,
      1   wm, iwm, f, jac, pjac, slvs, econ, lasty, lu_solver,
-     2   fnorm_computation)
+     2   fnorm_computation, step_size_callback, handle)
 clll. optimize
-      external f, jac, pjac, slvs, econ
+      external f, jac, pjac, slvs, econ, step_size_callback
       external solve
+      integer*8 handle
       integer neq, nyh, iwm
       integer iownd, ialth, ipup, lmax, meo, nqnyh, nslp,
      1   icf, ierpj, iersl, jcur, jstart, kflag, l, meth, miter,
@@ -257,7 +258,7 @@ c-----------------------------------------------------------------------
       do 230 i = 1,n
  230    y(i) = yh(i,1)
       call srcma (rsav, isav, 1)
-c     write(*, *), "call f 258"
+c     write(*, *), "call f 258", tn
       call f (neq, tn, y, savf)
 c     SCIPY error check:
       if (neq(1) .eq. -1) return
@@ -421,6 +422,7 @@ c-----------------------------------------------------------------------
       iredo = 0
       nst = nst + 1
       hu = h
+      call step_size_callback(handle, h)
       nqu = nq
       mused = meth
       do 460 j = 1,l
