@@ -17,22 +17,10 @@
 import sys
 from functools import partial
 
+from . import __version__
 from .compiler import LoadedModule, build_folder, compile_if_needed_and_load
 from .create_curry_class import create_interface_onary
-from .expressions import Max, Min, isnan
-from .function import Alias, Function, function_wrapper_factory
-from .globals import Globals
-from .integral import ERROR, Checked, IfThenElse, Integral
-from .interpolation import InterpolationFunction1D, InterpolationFunction1DWrapper
-from .ode import Ode
-from .ode_combined import OdeCombined
-from .ode_fast import OdeFast, read_known_traces, read_new_traces, write_known_traces
-from .python_function import PythonFunction
-from .symbol import Symbol
 from .utils import Hasher, align, concat_generator_results
-from .vector import Vector
-from .version import __version__
-from .visitor import Sp2CVisitor
 from .wrapper import WrapperBase
 
 
@@ -47,6 +35,8 @@ def _print_code_fragment(code, line_no, e, stream=sys.stderr, extra_lines=5):
 
 class Module(object):
     def __init__(self):
+        from .globals import Globals
+
         self.globals_ = Globals()
         self.functions = []
         self.python_functions = []
@@ -59,6 +49,13 @@ class Module(object):
         self._unique_id = None
 
     def add(self, what):
+        from .function import Function
+        from .globals import Globals
+        from .ode import Ode
+        from .ode_combined import OdeCombined
+        from .ode_fast import OdeFast
+        from .python_function import PythonFunction
+
         self._reset_unique_id()
         if isinstance(what, Function):
             self._add_function(what)
@@ -144,9 +141,20 @@ class Module(object):
             return ode
 
         def decl(*names, ns=None):
+
             for name in names:
                 exec("{name} = Symbol('{name}')".format(name=name), ns)
 
+        from .expressions import Max, Min, isnan
+        from .function import Alias, Function
+        from .integral import ERROR, Checked, IfThenElse, Integral
+        from .interpolation import InterpolationFunction1D
+        from .ode import Ode
+        from .ode_combined import OdeCombined
+        from .ode_fast import OdeFast
+        from .symbol import Symbol
+        from .vector import Vector
+
         ns = {
             "Function": add_function,
             "Integral": Integral,
@@ -188,6 +196,7 @@ class Module(object):
 
     @staticmethod
     def parse_sympy_code(code, locals_=None):
+        from .globals import Globals
 
         if locals_ is None:
             locals_ = {}
@@ -240,6 +249,8 @@ class Module(object):
         compilation_flags=None,
         force=False,
     ):
+        from .ode_fast import read_known_traces, read_new_traces, write_known_traces
+
         found_new_traces = False
         for ode in self.fast_odes:
             N = len(ode.rhs)
@@ -286,6 +297,8 @@ class ModuleWrapper(WrapperBase):
         self.combined_odes = module.combined_odes[:]
         self.python_functions = module.python_functions[:]
 
+        from .visitor import Sp2CVisitor
+
         self.visitor = Sp2CVisitor(self.globals_)
 
         self.function_wrappers = None
@@ -295,6 +308,8 @@ class ModuleWrapper(WrapperBase):
         self._unique_id = None
 
     def setup_wrappers(self, compile_fast_odes=False, traces=None):
+        from .function import function_wrapper_factory
+
         self.function_wrappers = [
             function_wrapper_factory(function, self.globals_, self.visitor)
             for function in self.functions
@@ -435,6 +450,8 @@ class ModuleWrapper(WrapperBase):
 
     def _pickling_code(self):
         names = []
+        from .interpolation import InterpolationFunction1DWrapper
+
         for name, w in self.visitor.extra_wrappers.items():
             if isinstance(w, InterpolationFunction1DWrapper):
                 names.append(str(name))
